#
# spec file for package python-pyVows
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-pyVows
Version:        3.0.0
Release:        3.1
Summary:        BDD test engine based on Vows.js
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/heynemann/pyvows
Source:         https://files.pythonhosted.org/packages/source/p/pyVows/pyVows-%{version}.tar.gz
BuildRequires:  %{python_module Unidecode}
BuildRequires:  %{python_module colorama >= 0.3.7}
BuildRequires:  %{python_module gevent >= 0.13.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module preggy >= 0.5.8}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-Unidecode
Requires:       python-gevent >= 1.2.2
Requires:       python-preggy >= 1.3.0
Recommends:     python-colorama >= 0.3.7
BuildArch:      noarch
%python_subpackages

%description
pyVows is a BDD test engine based on Vows.js <http://vowsjs.org>.

%prep
%setup -q -n pyVows-%{version}
sed -i '/^#!/d' pyvows/__main__.py pyvows/cli.py

%build
export LANG="en_US.UTF-8"
%pyproject_wheel

%install
export LANG="en_US.UTF-8"
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyvows
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG="en_US.UTF-8"
export PYTHONPATH=.
export PATH=%{buildroot}%{_bindir}:$PATH
%python_exec pyvows/cli.py -x tests/

%pre
# removing old update-alternatives entries
%python_libalternatives_reset_alternative pyvows

# post and postun macro call is not needed with only libalternatives

%files %{python_files}
%python_alternative %{_bindir}/pyvows
%{python_sitelib}/pyvows
%{python_sitelib}/py[Vv]ows-%{version}*-info

%changelog
* Wed Jun  4 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
- Convert to libalternatives
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Mar 11 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.0.0:
  * No upstream changelog, various fixes for Python 3.
- Drop patches no longer required:
  * pr_133.patch
  * py37-async-keyword.patch
* Thu Mar  7 2019 John Vandenberg <jayvdb@gmail.com>
- Add LANG="en_US.UTF-8" to fix build issue on Leap
* Thu Feb 21 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1.0
- Activate test suite
- Use single spec format for Python 2 & 3 rpms
- Adds patch pr_133.patch for Python 3 support, and
  py37-async-keyword.patch for Python 3.7 support.
* Fri Jan 10 2014 toms@opensuse.org
- Initial version 2.0.4
